@@ -1,28 +1,30 @@
 /* string-utils.c - Functions dealing with string contents.
  *
- * Copyright (C) 2001  Oskar Liljeblad
+ * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
+ * Oskar Liljeblad
  *
- * This file is part of the file renaming utilities (renameutils)
- * and regex-markup.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This software is copyrighted work licensed under the terms of the
- * GNU General Public License. Please consult the file `COPYING' for
- * details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __STRING_UTILS_H__
-#define __STRING_UTILS_H__
+#ifndef COMMON_STRING_UTILS_H
+#define COMMON_STRING_UTILS_H
 
-/* POSIX */
-#include <sys/types.h>
-#if HAVE_STDINT_H
-#include <stdint.h>
-#endif
-/* POSIX/gnulib */
-#include <stdbool.h>
-/* C89 */
-#include <ctype.h>		/* for toupper and tolower */
-/* common */
+#include <sys/types.h>		/* POSIX */
+#include <stdint.h>		/* POSIX/gnulib */
+#include <stdbool.h>		/* POSIX/gnulib */
+#include <ctype.h>		/* C89 - for toupper and tolower */
 #include "common.h"
 
 int strindex(const char *str, char ch);
