@@ -1,6 +1,6 @@
 /* icmd.c - Interactive mv(1) and cp(1).
  *
- * Copyright (C) 2001, 2002, 2004, 2005 Oskar Liljeblad
+ * Copyright (C) 2001, 2002, 2004, 2005, 2007 Oskar Liljeblad
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,30 +17,29 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#if HAVE_CONFIG_H
 #include <config.h>
-#endif
-#include <unistd.h> 	    	/* POSIX */
+#include <unistd.h> 	    	/* gnulib (POSIX) */
 #include <sys/stat.h>		/* POSIX */
+#include <signal.h> 	    	/* gnulib (POSIX) */
 #include <stdlib.h> 	    	/* C89 */
-#include <signal.h> 	    	/* C89 */
 #include <stdio.h>  	    	/* C89 */
 #include <errno.h>  	    	/* C89 */
-#include <locale.h> 	    	/* C89 */
-#include <stdbool.h>	    	/* Gnulib, C99, POSIX */
+#include <locale.h> 	    	/* gnulib (POSIX) */
+#include <stdbool.h>	    	/* gnulib (POSIX) */
 #include <readline/readline.h>	/* Readline */
 #include <readline/history.h>	/* Readline */
-#include <getopt.h>		/* Gnulib, GNU libc */
-#include "gettext.h"	    	/* Gnulib (gettext) */
+#include <getopt.h>		/* gnulib (POSIX) */
+#include <gettext.h>	    	/* gnulib (gettext) */
 #define _(s) gettext(s)
 #define N_(s) (s)
-#include "progname.h"	    	/* Gnulib */
-#include "quotearg.h"	    	/* Gnulib */
-#include "quote.h"		/* Gnulib */
-#include "yesno.h"  	    	/* Gnulib */
-#include "version-etc.h"    	/* Gnulib */
-#include "xalloc.h"		/* Gnulib */
-#include "dirname.h"		/* Gnulib */
+#include "configmake.h"		/* gnulib */
+#include "progname.h"	    	/* gnulib */
+#include "quotearg.h"	    	/* gnulib */
+#include "quote.h"		/* gnulib */
+#include "yesno.h"  	    	/* gnulib */
+#include "version-etc.h"    	/* gnulib */
+#include "xalloc.h"		/* gnulib */
+#include "dirname.h"		/* gnulib */
 #include "common/error.h"
 #include "common/io-utils.h"
 #include "common/string-utils.h"
@@ -49,14 +48,19 @@
 #define MV_COMMAND "mv"
 #define CP_COMMAND "cp"
 /* This list should be up to date with mv and cp!
- * It was last updated on 2005-08-12 for
- * Debian coreutils 5.2.1-2 in unstable.
+ * It was last updated on 2007-11-30 for
+ * Debian coreutils 5.97-5.4 in unstable.
+ *
+ * Do not include -t, --target-directory in this list!
+ *
+ * If you update these lists, don't forget to update the manual page as well!
  */
-#define MV_REQ_ARG_OPTIONS "S,V,reply,target-directory,suffix,version-control"
-#define CP_REQ_ARG_OPTIONS "S,V,no-preserve,sparse,suffix,version-control"
+#define MV_REQ_ARG_OPTIONS "S,reply,suffix"
+#define CP_REQ_ARG_OPTIONS "S,Z,no-preserve,sparse,suffix,context"
+
+const char version_etc_copyright[] = "Copyright (C) 2001, 2002, 2004, 2005, 2007 Oskar Liljeblad";
 
 static char *first_text = NULL;
-const char version_etc_copyright[] = "Copyright (C) 2001, 2002, 2004, 2005 Oskar Liljeblad";
 
 static int
 insert_first_text(void)
@@ -73,17 +77,15 @@ int_signal_handler(int signal)
 }
 
 static void
-display_help(const char *command)
+display_help(void)
 {
     printf(_("Usage: %s [OPTION] FILE...\n"), program_name);
-    if (strcmp(base_name(program_name), "imv") == 0) {
-        printf(_("Rename a file by editing the destination name using GNU readline.\n"));
-    } else {
-        printf(_("Copy a file by editing the destination name using GNU readline.\n"));
-    }
-    printf(_("All options except the options listed below are passed to %s.\n\n"), command);
-    printf(_("      --command=FILE         command to run instead of default %s\n"), command);
+    printf(_("Rename (imv) or copy a file (icp) by editing the destination name using\n"
+             "GNU Readline. All options except those listed below are passed on to mv,\n"
+             "cp, or the command specified by --command.\n\n"));
+    printf(_("      --command=FILE         command to run instead of default mv/cp\n"));
     printf(_("      --arg-options=OPTIONS  list of options that require an argument\n"));
+    printf(_("      --pass-through         run the command if two or more arguments are specified\n"));
     printf(_("      --help                 display this help and exit\n"));
     printf(_("      --version              output version information and exit\n"));
     printf(_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
@@ -93,18 +95,20 @@ display_help(const char *command)
  * XXX: move to strutil.c or something. Also in gmediaserver and microdc.
  */
 bool
-csv_contains(const char *csv, char sep, const char *value)
+string_in_csv(const char *csv, char sep, const char *value)
 {
     const char *p0;
     const char *p1;
-
+    size_t len;
+    
+    len = strlen(value);
     for (p0 = csv; (p1 = strchr(p0, sep)) != NULL; p0 = p1+1) {
-        if (strncmp(p0, value, p1-p0) == 0)
-            return true;
+        if (p1-p0 == len && strncmp(p0, value, len) == 0)
+            return true;                                 
     }
     if (strcmp(p0, value) == 0)
         return true;
-
+    
     return false;
 }
 
@@ -120,8 +124,6 @@ trim(char *str)
         memcpy(str, str+h, t-h+1);
 }
 
-
-
 int
 main(int argc, char **argv)
 {
@@ -130,34 +132,38 @@ main(int argc, char **argv)
     bool skip_opt_arg = false;
     bool posixly_correct;
     bool has_target_dir = false;
+    bool pass_through = false;
     char *last_long_opt = NULL;
     char last_short_opt = '\0';
     char *arg_options = "";
-    char *command;
+    char *command = NULL;
     char *files[argc];
     /*char *opts[argc];*/
     int file_count = 0;
     /*int opt_count = 0;*/
     struct stat sb;
     char *srcfile;
+    char *srcfile_stripped;
+    char *program_base_name;
     int c;
     int first_cmd_opt;
 
     set_program_name(argv[0]);
-    if (strcmp(base_name(program_name), "imv") != 0 && strcmp(base_name(program_name), "icp") != 0)
-        die(_("must be started as either `imv' or `icp'"));
+    program_base_name = base_name(program_name);
 
     if (setlocale(LC_ALL, "") == NULL)
-    	die_errno(_("cannot set locale"));
-    if (bindtextdomain (PACKAGE, LOCALEDIR) == NULL)
-    	die_errno(_("cannot bind message domain"));
-    if (textdomain (PACKAGE) == NULL)
-    	die_errno(_("cannot set message domain"));
+        warn(_("cannot set locale: %s\n"), errstr);
+#ifdef ENABLE_NLS
+    if (bindtextdomain(PACKAGE, LOCALEDIR) == NULL)
+        warn(_("cannot bind message domain: %s\n"), errstr);
+    if (textdomain(PACKAGE) == NULL)
+        warn(_("cannot set message domain: %s\n"), errstr);
+#endif
 
-    if (strcmp(base_name(program_name), "imv") == 0) {
+    if (strcmp(program_base_name, "imv") == 0) {
         arg_options = MV_REQ_ARG_OPTIONS;
         command = MV_COMMAND;
-    } else {
+    } else if (strcmp(program_base_name, "icp") == 0)  {
         arg_options = CP_REQ_ARG_OPTIONS;
         command = CP_COMMAND;
     }
@@ -166,7 +172,7 @@ main(int argc, char **argv)
         char *arg = argv[c];
 
         if (strcmp(arg, "--help") == 0) {
-            display_help(command);
+            display_help();
             exit(EXIT_SUCCESS);
         } else if (strcmp(arg, "--version") == 0) {
             version_etc(stdout, base_name(program_name), PACKAGE, VERSION, "Oskar Liljeblad", NULL);
@@ -179,6 +185,8 @@ main(int argc, char **argv)
             if (++c >= argc)
                 die(_("option `--%s' requires an argument"), arg+2);
             arg_options = argv[c];
+        } else if (strcmp(arg, "--pass-through") == 0) {
+            pass_through = true;
         } else if (strncmp(arg, "--command=", 10) == 0) {
             command = arg+10;
         } else if (strncmp(arg, "--arg-options=", 14) == 0) {
@@ -187,16 +195,20 @@ main(int argc, char **argv)
             break;
         }
     }
+
+    if (command == NULL && strcmp(program_base_name, "imv") != 0 && strcmp(program_base_name, "icp") != 0)
+        die(_("must be started as either `imv' or `icp', or --command must be specified"));
+
     first_cmd_opt = c;
 
     memset(&action, 0, sizeof(sigaction));
     action.sa_handler = int_signal_handler;
     action.sa_flags = SA_RESTART;
     if (sigaction(SIGINT, &action, NULL) < 0)
-	die_errno(NULL);
+	die(_("cannot register signal handler - %s\n"), errstr);
     action.sa_handler = SIG_IGN;
     if (sigaction(SIGQUIT, &action, NULL) < 0)
-	die_errno(NULL);
+	die(_("cannot register signal handler - %s\n"), errstr);
 
     posixly_correct = getenv("POSIXLY_CORRECT") != NULL;
 
@@ -218,7 +230,7 @@ main(int argc, char **argv)
         } else if (arg[0] == '-' && arg[1] == '-') {
             /*opts[opt_count++] = arg;*/
             if (strchr(arg, '=') == NULL) {
-                if (csv_contains(arg_options, ',', arg+2)) {
+                if (string_in_csv(arg_options, ',', arg+2)) {
                     skip_opt_arg = true;
                     last_long_opt = arg+2;
                     last_short_opt = '\0';
@@ -230,7 +242,7 @@ main(int argc, char **argv)
             /*opts[opt_count++] = arg;*/
             for (d = 1; arg[d] != '\0'; d++) {
                 char option[2] = { arg[d], '\0' };
-                if (csv_contains(arg_options, ',', option)) {
+                if (string_in_csv(arg_options, ',', option)) {
                     skip_opt_arg = true;
                     last_long_opt = NULL;
                     last_short_opt = arg[d];
@@ -259,6 +271,11 @@ main(int argc, char **argv)
 	exit(EXIT_FAILURE);
     }
 
+    if (!pass_through && file_count > 1) {
+        warn(_("too many arguments"));
+        exit(EXIT_FAILURE);
+    }
+
     if (file_count > 1 || has_target_dir) { /* Pass everything as is to command */
         char *args[argc-first_cmd_opt+3];
 
@@ -302,21 +319,23 @@ main(int argc, char **argv)
     /* We usually don't want trailing slashes in the edited file name.
      * This is a matter of taste though.
      */
-    for (c = strlen(srcfile); c > 0 && srcfile[c-1] == '/'; c--)
-    srcfile[c] = '\0';
+    srcfile_stripped = xstrdup(srcfile);
+    strip_trailing_slashes(srcfile_stripped);
 
     rl_readline_name = base_name(program_name);
-    first_text = xstrdup(srcfile);
+    first_text = xstrdup(srcfile_stripped);
     for (;;) {
         char *newname;
 
-	add_history(srcfile);
+	add_history(srcfile_stripped);
 	rl_startup_hook = insert_first_text;
 	newname = readline("> ");
 
 	if (newname != NULL) {
 	    trim(newname);
-	    if (strcmp(newname, "") != 0 && strcmp(newname, srcfile) != 0) {
+	    strip_trailing_slashes(newname);
+
+	    if (newname[0] != '\0' && strcmp(newname, srcfile_stripped) != 0) {
 	        char *args[argc-first_cmd_opt+5];
 
                 if (file_exists(newname)) {
@@ -329,6 +348,7 @@ main(int argc, char **argv)
                     }
                 }
 
+                free(srcfile_stripped);
                 memcpy(args+1, argv+first_cmd_opt, (argc-first_cmd_opt+1) * sizeof(char *));
                 if (posixly_correct || no_more_opts) {
                     args[argc-first_cmd_opt+1] = newname;
@@ -350,6 +370,7 @@ main(int argc, char **argv)
             puts("");
 
         warn(_("no changes made"));
+        free(srcfile_stripped);
         exit(EXIT_SUCCESS);
     }
 }
