@@ -1,6 +1,6 @@
 /* commandmode.c - Interpreter and completion for the interactive mode.
  *
- * Copyright (C) 2001, 2002, 2004, 2005 Oskar Liljeblad
+ * Copyright (C) 2001, 2002, 2004, 2005, 2007 Oskar Liljeblad
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,32 +17,32 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#if HAVE_CONFIG_H
 #include <config.h>
-#endif
-#include <sys/types.h>	    	    /* POSIX */
+#include <sys/types.h>	    	    	/* POSIX */
 #if HAVE_SYS_WAIT_H
-# include <sys/wait.h>	    	    /* POSIX */
+# include <sys/wait.h>	    	    	/* POSIX */
 #endif
-#include <unistd.h> 	    	    	/* POSIX */
+#include <unistd.h> 	    	    	/* gnulib (POSIX) */
 #if HAVE_WORDEXP_H
 #include <wordexp.h>	    	    	/* POSIX */
 #endif
-#include <signal.h> 	    	    	/* C89 */
+#include <signal.h> 	    	    	/* gnulib (POSIX) */
 #include <errno.h>  	    	    	/* C89 */
 #include <stdio.h>  	    	    	/* C89 */
 #include <stdlib.h> 	    	    	/* C89 */
 #include <readline/readline.h>	    	/* GNU Readline */
 #include <readline/history.h>	    	/* GNU Readline */
-#include "stdbool.h"			/* Gnulib (POSIX) */
-#include "quotearg.h"	    	    	/* Gnulib */
-#include <gettext.h> 	    	    	/* Gnulib (gettext) */
+#include <stdbool.h>			/* gnulib (POSIX) */
+#include <gettext.h> 	    	    	/* gnulib (gettext) */
 #define _(s) gettext(s)
 #define N_(s) (s)
+#include "progname.h"			/* gnulib */
+#include "quotearg.h"	    	    	/* gnulib */
+#include "xalloc.h"			/* gnulib */
+#include "xvasprintf.h"			/* gnulib */
+#include "version-etc.h"		/* gnulib */
 #include "common/common.h"
-#include "xalloc.h"			/* Gnulib */
-#include "xvasprintf.h"			/* Gnulib */
-#include "version-etc.h"		/* Gnulib */
+#include "common/comparison.h"
 #include "common/string-utils.h"
 #include "common/error.h"
 #include "qcmd.h"
@@ -200,7 +200,7 @@ commandmode_mainloop(void)
     struct sigaction action;
     char *prompt;
 
-    rl_readline_name = program_invocation_name;
+    rl_readline_name = program_name;
     rl_attempted_completion_function = completion;
     rl_basic_word_break_characters = " \t\n\"\\'`@$><=;|&{(,";
 
