@@ -1,6 +1,6 @@
 /* plan.c - Checking renames and resolving rename order.
  *
- * Copyright (C) 2001, 2002, 2004, 2005 Oskar Liljeblad
+ * Copyright (C) 2001, 2002, 2004, 2005, 2007 Oskar Liljeblad
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,17 +17,15 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#if HAVE_CONFIG_H
 #include <config.h>
-#endif
-#include <stdlib.h> 	    	/* C89 */
-#include <string.h> 	    	/* C89 */
-#include <stdbool.h>	    	/* Gnulib (POSIX) */
-#include <gettext.h> 	    	/* Gnulib (gettext) */
+#include <stdlib.h> 	    		/* C89 */
+#include <string.h> 	    		/* gnulib (C89) */
+#include <stdbool.h>	    		/* gnulib (POSIX) */
+#include <gettext.h> 	    		/* gnulib (gettext) */
 #define _(s) gettext(s)
 #define N_(s) (s)
-#include "xalloc.h"		/* Gnulib */
-#include "xvasprintf.h"		/* Gnulib */
+#include "xalloc.h"			/* gnulib */
+#include "xvasprintf.h"			/* gnulib */
 #include "common/io-utils.h"
 #include "common/string-utils.h"
 #include "common/common.h"
